django-locations
================

A small reusable locations app for Django.  Formally apart of the Hadrian project.

This supports Python 3 **only**


Installation 
------------

Installing from Source (This package is not available on Pypi)

    pip install git+git://github.com/dstegelman/django-locations.git@master#egg=locations
    
    
Add to installed apps.

More docs coming soon.
